@@ -322,14 +322,10 @@ class BaseJAAQLController:
             if len(request.data.decode(request.charset)) != 0:
                 raise HttpStatusException(ERR__unexpected_request_body, HTTPStatus.BAD_REQUEST)
 
-        if not was_allow_all or not isinstance(data, list):
-            if isinstance(data, list) and not was_allow_all:
-                raise HttpStatusException("Did not expect list type for input", HTTPStatus.BAD_REQUEST)
-            combined_data = {**request.form, **request.args, **data}
-            if len(combined_data) != len(request.form) + len(request.args) + len(data):
-                raise HttpStatusException(ERR__duplicated_field, HTTPStatus.BAD_REQUEST)
-        else:
-            combined_data = data
+        combined_data = {**request.form, **request.args, **data}
+
+        if len(combined_data) != len(request.form) + len(request.args) + len(data):
+            raise HttpStatusException(ERR__duplicated_field, HTTPStatus.BAD_REQUEST)
 
         if not was_allow_all:
             BaseJAAQLController.validate_data(method, combined_data, is_prod, fill_missing)
@@ -402,16 +398,11 @@ class BaseJAAQLController:
         def wrap_func(view_func):
             @wraps(view_func)
             def routed_function(view_func_local):
-                if not self.model.has_installed and not route.startswith('/internal'):
-                    resp = Response("Still installing. Be patient", status=HTTPStatus.SERVICE_UNAVAILABLE)
-                    self._cors(resp)
-                    return resp
-
                 request_id = uuid.uuid4()
                 self.perform_profile(request_id, route=route, method=request.method)
                 start_time = datetime.now()
                 resp = None
-                resp_type = "application/json"
+                resp_type = current_app.config["JSONIFY_MIMETYPE"]
                 jaaql_resp = JAAQLResponse()
                 jaaql_resp.response_type = resp_type
 
